<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

/**
 * @OA\RequestBody(
 *   request="UpdateGame",
 *   required=true,
 *   @OA\JsonContent(
 *     required={"state"},
 *       @OA\Property(
 *         property="state",
 *         type="string",
 *         pattern="^playing|finished$"
 *       ),
 *       @OA\Property(
 *       property="users",
 *       type="array",
 *       description="Users who participated in the game. Only needed when state == finished",
 *       @OA\Items(
 *         @OA\Property(
 *           property="id",
 *           type="int",
 *           description="ID of the user"
 *         )
 *       )
 *     ),
 *   ),
 * ),
 */
class UpdateGameRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'state' => 'required|string|in:playing,finished',
            "users" => "required_if:state,finished|array|min:2",
            "users.*.id" => "required_with:users|exists:users,id|distinct"
        ];
    }
}
