<?php

use App\Http\Controllers\Client;
use App\Http\Controllers\Server;
use App\Http\Controllers\Shared;

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::prefix('auth')->middleware('api')->group(function () {
    Route::post('login', [Client\AuthController::class, 'login']);
    Route::post('register', [Client\AuthController::class, 'register']);
    Route::post('recover', [Client\AuthController::class, 'recover']);

    Route::middleware('auth:client')->group(function () {
        Route::post('logout', [Client\AuthController::class, 'logout']);
        Route::post('refresh', [Client\AuthController::class, 'refresh']);
    
        Route::get('profile', [Client\ProfileController::class, 'show']);
        Route::put('profile', [Client\ProfileController::class, 'update']);
        Route::delete('profile', [Client\ProfileController::class, 'destroy']);
    });

    Route::prefix('server')->group(function() {
        Route::post('login', [Server\AuthController::class, 'login']);
        Route::middleware('auth:server')->group(function () {
            Route::post('logout', [Server\AuthController::class, 'logout']);
            Route::post('refresh', [Server\AuthController::class, 'refresh']);
            Route::get('profile', [Server\AuthController::class, 'profile']);
            Route::post('heartbeat', [Server\AuthController::class, 'heartbeat']);
        });
    });
    
});

Route::middleware(['api', 'auth:client'])->group(function () {
    Route::apiResource('server', Shared\ServerController::class);
    Route::apiResource('user', Shared\UserController::class, ['only' => ['index', 'show']]);
    Route::apiResource('game', Shared\GameController::class, ['only' => ['index', 'show']]);
    Route::get('server/{id}/game' , [Shared\ServerController::class , 'index_games']);
    Route::get('user/{id}/game' , [Shared\UserController::class , 'index_usergame']);
    Route::get('game/{id}/user' , [Shared\GameController::class , 'index_users']);
    Route::get('server/{id}/game/{game_id}' , [Shared\ServerController::class , 'show_games']);
    Route::get('user/{id}/game/{game_id}' , [Shared\UserController::class , 'show_usergame']);
    Route::get('game/{id}/user/{user_id}' , [Shared\GameController::class , 'show_users']);

    Route::post('server/{id}/connect', [Client\ConnectController::class, 'connect']);
});

Route::middleware(['api', 'auth:server'])->group(function () {
    Route::post('user/{id}/accept', [server\AcceptController::class, 'accept']);
    Route::post('user/{id}/disconnect', [server\DisconnectController::class, 'disconnect']);
    Route::resource('game', Shared\GameController::class, ['only' => ['store', 'update']]);
});

Route::fallback(function () {
    abort(404, 'API resource not found');
});
